var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvwxyz~",
  1: "_abcdefghiklmnopqrstuvwxz",
  2: "oprs",
  3: "abcdeghimnoprstuvw",
  4: "_abcdefghiklmnopqrstuvwxyz~",
  5: "_abcdefghijklmnopqrstuvwxyz",
  6: "_abcdefghiklmnopqrstuvwxz",
  7: "abcdefghilmnopqrstuvwx",
  8: "abcdefghiklmnopqrstuvwz",
  9: "cdlnps",
  10: "abcdefghilmnoprstvw",
  11: "_acdefghimnoprstuvw",
  12: "acdegilmoprst",
  13: "abcdghilmoprstuw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "properties",
  10: "related",
  11: "defines",
  12: "groups",
  13: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Properties",
  10: "Friends",
  11: "Macros",
  12: "Modules",
  13: "Pages"
};

